==> kscreen-5.2.2.tar.xz: kscreen-5.2.2/kded/kscreen.desktop.cmake <==
[Desktop Entry]
Name=KScreen 2
Name[bs]=KScreen 2
Name[ca]=KScreen 2
Name[cs]=KScreen 2
Name[de]=KScreen 2
Name[en_GB]=KScreen 2
Name[es]=KScreen 2
Name[fi]=KScreen 2
Name[fr]=KScreen 2
Name[it]=KScreen 2
Name[nb]=KScreen 2
Name[nl]=KScreen 2
Name[pl]=KEkran 2
Name[pt]=KScreen 2
Name[pt_BR]=KScreen 2
Name[sk]=KScreen 2
Name[sl]=KScreen 2
Name[sr]=К‑екран 2
Name[sr@ijekavian]=К‑екран 2
Name[sr@ijekavianlatin]=K‑ekran 2
Name[sr@latin]=K‑ekran 2
Name[sv]=Kscreen 2
Name[uk]=KScreen 2
Name[x-test]=xxKScreen 2xx
Name[zh_CN]=KScreen 2
Name[zh_TW]=KScreen 2
Comment=Screen management
Comment[bs]=Upravljanje ekranom
Comment[ca]=Gestió de pantalla
Comment[cs]=Správa obrazovek
Comment[de]=Bildschirm-Verwaltung
Comment[en_GB]=Screen management
Comment[es]=Gestión de la pantalla
Comment[fi]=Näyttöjen hallinta
Comment[fr]=Gestion d'écrans
Comment[it]=Gestione dello schermo
Comment[nb]=Skjembehandling
Comment[nl]=Schermbeheer
Comment[pl]=Zarządzanie ekranem
Comment[pt]=Gestão do ecrã
Comment[pt_BR]=Gerenciamento de telas
Comment[sk]=Správa obrazoviek
Comment[sl]=Upravljanje zaslonov
Comment[sr]=Управљање екраном
Comment[sr@ijekavian]=Управљање екраном
Comment[sr@ijekavianlatin]=Upravljanje ekranom
Comment[sr@latin]=Upravljanje ekranom
Comment[sv]=Skärmhantering
Comment[uk]=Керування екраном
Comment[x-test]=xxScreen managementxx
Comment[zh_CN]=屏幕管理
Comment[zh_TW]=螢幕管理

Type=Service
Icon=preferences-system-power-management
X-KDE-ServiceTypes=KDEDModule
X-KDE-Library=kscreen
X-KDE-DBus-ModuleName=kscreen
X-KDE-Kded-autoload=true
X-KDE-Kded-load-on-demand=false
X-KDE-Kded-phase=1
X-KDE-PluginInfo-Version=@KSCREEN_VERSION@

==> kscreen-5.2.95.tar.xz: kscreen-5.2.95/kded/kscreen.desktop.cmake <==
[Desktop Entry]
Name=KScreen 2
Name[bs]=KScreen 2
Name[ca]=KScreen 2
Name[cs]=KScreen 2
Name[de]=KScreen 2
Name[el]=KScreen 2
Name[en_GB]=KScreen 2
Name[es]=KScreen 2
Name[fi]=KScreen 2
Name[fr]=KScreen 2
Name[gl]=KScreen 2
Name[hu]=KScreen 2
Name[it]=KScreen 2
Name[nb]=KScreen 2
Name[nl]=KScreen 2
Name[pa]=KScreen 2
Name[pl]=KEkran 2
Name[pt]=KScreen 2
Name[pt_BR]=KScreen 2
Name[sk]=KScreen 2
Name[sl]=KScreen 2
Name[sr]=К‑екран 2
Name[sr@ijekavian]=К‑екран 2
Name[sr@ijekavianlatin]=K‑ekran 2
Name[sr@latin]=K‑ekran 2
Name[sv]=Kscreen 2
Name[tr]=KScreen 2
Name[uk]=KScreen 2
Name[x-test]=xxKScreen 2xx
Name[zh_CN]=KScreen 2
Name[zh_TW]=KScreen 2
Comment=Screen management
Comment[bs]=Upravljanje ekranom
Comment[ca]=Gestió de pantalla
Comment[cs]=Správa obrazovek
Comment[de]=Bildschirm-Verwaltung
Comment[el]=Διαχείριση οθόνης
Comment[en_GB]=Screen management
Comment[es]=Gestión de la pantalla
Comment[fi]=Näyttöjen hallinta
Comment[fr]=Gestion d'écrans
Comment[gl]=Xestor de pantalla
Comment[hu]=Képernyőkezelés
Comment[it]=Gestione dello schermo
Comment[nb]=Skjembehandling
Comment[nl]=Schermbeheer
Comment[pa]=ਸਕਰੀਨ ਪਰਬੰਧ
Comment[pl]=Zarządzanie ekranem
Comment[pt]=Gestão do ecrã
Comment[pt_BR]=Gerenciamento de telas
Comment[sk]=Správa obrazoviek
Comment[sl]=Upravljanje zaslonov
Comment[sr]=Управљање екраном
Comment[sr@ijekavian]=Управљање екраном
Comment[sr@ijekavianlatin]=Upravljanje ekranom
Comment[sr@latin]=Upravljanje ekranom
Comment[sv]=Skärmhantering
Comment[tr]=Ekran yönetimi
Comment[uk]=Керування екраном
Comment[x-test]=xxScreen managementxx
Comment[zh_CN]=屏幕管理
Comment[zh_TW]=螢幕管理

Type=Service
Icon=preferences-system-power-management
X-KDE-ServiceTypes=KDEDModule
X-KDE-Library=kscreen
X-KDE-DBus-ModuleName=kscreen
X-KDE-Kded-autoload=true
X-KDE-Kded-load-on-demand=false
X-KDE-Kded-phase=1
X-KDE-PluginInfo-Version=@KSCREEN_VERSION@
